# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased] - xxxx-xx-xx

### Added

### Changed

### Fixed

### Removed


## [v0.1.2] - 2020-01-20

### Added
- Support for python 3.7 at CI's #untracked
- CircleCI CI builds #untracked
- CodeClimate CI builds #untracked

### Changed
- removed unittest in favor of pytest #60
- Tests dependencies now have requirements files #untracked

### Fixed
- Travis CI builds #untracked
- Appveyor CI builds #untracked

### Removed
- Support for python 2.7 will ends at 2020 #untracked


## [v0.1.1] - 2019-09-15

### Added
- This CHANGELOG #untracked

### Changed

### Fixed

### Removed
- Dependency reading files at setup.py #untracked
- Old references to qacode


[Unreleased]: https://github.com/netzulo/qatestlink/compare/v0.1.2...HEAD
[0.1.2]: https://github.com/netzulo/qatestlink/compare/v0.1.1...v0.1.2
[0.1.1]: https://github.com/netzulo/qatestlink/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/netzulo/qatestlink/compare/v0.0.9...v0.1.0
[0.0.9]: https://github.com/netzulo/qatestlink/compare/v0.0.8...v0.0.9
[0.0.8]: https://github.com/netzulo/qatestlink/compare/v0.0.7...v0.0.8
[0.0.7]: https://github.com/netzulo/qatestlink/compare/v0.0.6...v0.0.7
[0.0.6]: https://github.com/netzulo/qatestlink/compare/v0.0.5...v0.0.6
[0.0.4]: https://github.com/netzulo/qatestlink/compare/v0.0.3...v0.0.5
[0.0.3]: https://github.com/netzulo/qatestlink/compare/v0.0.2...v0.0.3
[0.0.2]: https://github.com/netzulo/qatestlink/compare/v0.0.1...v0.0.2
[0.0.1]: https://github.com/netzulo/qatestlink/compare/v0.0.0...v0.0.1